@@ -1,6 +1,6 @@
 package Sub::Spec::Pod;
 BEGIN {
-  $Sub::Spec::Pod::VERSION = '0.02';
+  $Sub::Spec::Pod::VERSION = '0.03';
 }
 # ABSTRACT: Generate POD documentation for subs
 
@@ -22,6 +22,7 @@ sub _parse_schema {
 }
 
 sub _gen_sub_pod($;$) {
+    require Data::Dump;
     require Data::Dump::Partial;
     require List::MoreUtils;
 
@@ -45,58 +46,73 @@ sub _gen_sub_pod($;$) {
 
     my $args  = $sub_spec->{args} // {};
     my $rargs = $sub_spec->{required_args};
+    my $has_cat = grep { $_->[1]{arg_category} } values %$args;
     $args = { map {$_ => _parse_schema($args->{$_})} keys %$args };
-    my $prev_cat;
-    for my $name (sort {
-        (($args->{$a}{attr_hashes}[0]{arg_category} // "") cmp
-             ($args->{$b}{attr_hashes}[0]{arg_category} // "")) ||
-                 (($args->{$a}{attr_hashes}[0]{arg_pos} // 9999) <=>
-                      ($args->{$b}{attr_hashes}[0]{arg_pos} // 9999)) ||
-                          ($a cmp $b) } keys %$args) {
-        my $arg = $args->{$name};
-        my $ah0 = $arg->{attr_hashes}[0];
 
-        my $cat = $ah0->{arg_category} // "";
-        if (!defined($prev_cat) || $prev_cat ne $cat) {
-            $pod .= ($cat ? "$cat arguments" : "Arguments") .
-                " (* denotes required arguments):\n\n";
-            $pod .= "=back\n\n" if defined($prev_cat);
-            $pod .= "=over 4\n\n";
-            $prev_cat = $cat;
+    if (scalar keys %$args) {
+        my $prev_cat;
+        for my $name (sort {
+            (($args->{$a}{attr_hashes}[0]{arg_category} // "") cmp
+                 ($args->{$b}{attr_hashes}[0]{arg_category} // "")) ||
+                     (($args->{$a}{attr_hashes}[0]{arg_pos} // 9999) <=>
+                          ($args->{$b}{attr_hashes}[0]{arg_pos} // 9999)) ||
+                              ($a cmp $b) } keys %$args) {
+            my $arg = $args->{$name};
+            my $ah0 = $arg->{attr_hashes}[0];
+
+            my $cat = $ah0->{arg_category} // "";
+            if (!defined($prev_cat) || $prev_cat ne $cat) {
+                $pod .= "=back\n\n" if defined($prev_cat);
+                $pod .= ($cat ? ucfirst("$cat arguments") :
+                             ($has_cat ? "General arguments":"Arguments")) .
+                                 " (C<*> denotes required arguments):\n\n";
+                $pod .= "=over 4\n\n";
+                $prev_cat = $cat;
+            }
+
+            $pod .= "=item * $name".($ah0->{required} ? "*" : "")." => ";
+            my $type;
+            if ($arg->{type} eq 'any') {
+                my @schemas = map {_parse_schema($_)} @{$ah0->{of}};
+                my @types   = map {$_->{type}} @schemas;
+                @types      = sort List::MoreUtils::uniq(@types);
+                $type       = join("|", @types);
+            } else {
+                $type       = $arg->{type};
+            }
+            $pod .= "I<$type>";
+            $pod .= " (default ".
+                (defined($ah0->{default}) ?
+                     "C<".Data::Dump::Partial::dumpp($ah0->{default}).">"
+                         : "none").
+                             ")"
+                               if defined($ah0->{default});
+            $pod .= "\n\n";
+
+            $pod .= "One of:\n\n".
+                join("", map {" $_\n"} split /\n/,
+                     Data::Dump::dump($ah0->{choices}))."\n\n"
+                           if defined($ah0->{choices});
+
+            #my $o = $ah0->{arg_pos};
+            #my $g = $ah0->{arg_greedy};
+
+            $pod .= "$ah0->{summary}.\n\n" if $ah0->{summary};
+
+            my $desc = $ah0->{description};
+            if ($desc) {
+                $desc =~ s/^\n+//; $desc =~ s/\n+$//;
+                # XXX format/rewrap
+                $pod .= "$desc\n\n";
+            }
         }
+        $pod .= "=back\n\n";
 
-        $pod .= "=item * $name".($ah0->{required} ? "*" : "")." => ";
-        if ($arg->{type} eq 'any') {
-            my @schemas = map {_parse_schema($_)} @{$ah0->{of}};
-            my @types   = map {$_->{type}} @schemas;
-            @types      = sort List::MoreUtils::uniq(@types);
-            $pod .= uc join("|", @types);
-        } else {
-            $pod .= uc $arg->{type};
-        }
-        $pod .= " (default ".
-            (defined($ah0->{default}) ?
-                 Data::Dump::Partial::dumpp($ah0->{default}) : "none").
-                       ")\n\n"
-                           if defined($ah0->{default});
+    } else {
 
-        $pod .= "One of: ".
-            Data::Dump::Partial::dumpp($ah0->{choices})."\n\n"
-                  if defined($ah0->{choices});
+        $pod .= "No known arguments at this time.\n\n";
 
-             #my $o = $ah0->{arg_pos};
-        #my $g = $ah0->{arg_greedy};
-
-        $pod .= "$ah0->{summary}.\n\n" if $ah0->{summary};
-
-        my $desc = $ah0->{description};
-        if ($desc) {
-            $desc =~ s/^\n+//; $desc =~ s/\n+$//;
-            # XXX format/rewrap
-            $pod .= "$desc\n\n";
-        }
     }
-    $pod .= "=back\n\n";
 
     $pod;
 }
@@ -139,7 +155,7 @@ Sub::Spec::Pod - Generate POD documentation for subs
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -160,11 +176,11 @@ Example output:
 
  =over 4
 
- =item * arg1* => int (default 0)
+ =item * arg1* => INT (default 0)
 
  Blah ...
 
- =item * arg2 => str (default none)
+ =item * arg2 => STR (default none)
 
  Blah blah ...
 
